Module common

Module common 

Shared types used across endpoints Shared types used across Exa API endpoints

Structs

ContentsOptions
Options for what content to retrieve with search results
CostDollars
Represents the total cost breakdown for a request.
CostDollarsContents
Represents the cost breakdown related to contents retrieval. Fields are optional because only non-zero costs are included by the API.
CostDollarsSearch
Represents the cost breakdown related to search. Fields are optional because only non-zero costs are included by the API.
HighlightsContentsOptions
Options for highlight content retrieval
SearchResult
A single search result from the Exa API
SummaryContentsOptions
Options for summary content retrieval
TextContentsOptions
Options for text content retrieval

Enums

LivecrawlOption
Livecrawl option for content retrieval
SearchType
Search type for Exa queries