Shared types used across endpoints Shared types used across Exa API endpoints
Structs
- Contents
Options - Options for what content to retrieve with search results
- Cost
Dollars - Represents the total cost breakdown for a request.
- Cost
Dollars Contents - Represents the cost breakdown related to contents retrieval. Fields are optional because only non-zero costs are included by the API.
- Cost
Dollars Search - Represents the cost breakdown related to search. Fields are optional because only non-zero costs are included by the API.
- Highlights
Contents Options - Options for highlight content retrieval
- Search
Result - A single search result from the Exa API
- Summary
Contents Options - Options for summary content retrieval
- Text
Contents Options - Options for text content retrieval
Enums
- Livecrawl
Option - Livecrawl option for content retrieval
- Search
Type - Search type for Exa queries